@@ -12,8 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Email-Reminder; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-# USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+# 02110-1301, USA.
 
 package EmailReminder::AnniversaryEvent;
 
@@ -99,7 +99,7 @@ Subject: $subject
 
 Hi $first_name,
 
-I just want to remind you that the ${occurence_string}anniversay ${special_name}of $name and $partner_name is $when.$email_message
+I just want to remind you that the ${occurence_string}anniversary ${special_name}of $name and $partner_name is $when.$email_message
 MESSAGEEND
 
     return $message;
