@@ -12,8 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with Email-Reminder; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-# USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+# 02110-1301, USA.
 
 package EmailReminder::Event;
 
@@ -24,21 +24,24 @@ package EmailReminder::Event;
 use strict;
 use warnings;
 
+use Date::Manip;
 use XML::DOM;
 
 use EmailReminder::Utils;
 
 require Exporter;
 our @ISA = ("Exporter");
-our @EXPORT = qw(is_occurring get_reminder_email get_reminder_name);
+our @EXPORT = qw(is_occurring get_recipients);
 
 # XML tags, attributes and values
 
 my $REMINDER_TAG = 'reminder';
 my $REMINDERS_TAG = 'reminders';
-my $REMINDER_NAME_TAG = 'reminder-name';
-my $REMINDER_EMAIL_TAG = 'reminder-email';
+my $RECIPIENT_TAG = 'recipient';
+my $RECIPIENTS_TAG = 'recipients';
 
+my $EMAIL_ATTR = 'email';
+my $NAME_ATTR = 'name';
 my $TYPE_ATTR = 'type';
 
 my $DAYS_BEFORE_VAL = 'days before';
@@ -77,8 +80,11 @@ sub new
     }
 
     # Where to send this reminder email
-    $this->{REMINDER_NAME} = EmailReminder::Utils::get_node_value($this->{XML_NODE}, $REMINDER_NAME_TAG);
-    $this->{REMINDER_EMAIL} = EmailReminder::Utils::get_node_value($this->{XML_NODE}, $REMINDER_EMAIL_TAG);
+    my $recipients = $this->{XML_NODE}->getElementsByTagName($RECIPIENTS_TAG)->item(0);
+    if (defined($recipients)) {
+        $this->{RECIPIENTS_NODE} = $recipients;
+        $this->{RECIPIENTS_CACHE} = $this->get_recipients();
+    }
 
     # Process reminders
     my $reminders = $this->{XML_NODE}->getElementsByTagName($REMINDERS_TAG)->item(0);
@@ -98,6 +104,28 @@ sub unlink
     $node->dispose();
 }
 
+sub get_recipients
+{
+    my $this = shift;
+
+    if (!defined($this->{RECIPIENTS_CACHE})) {
+        my @recipients = ();
+
+        if (defined($this->{RECIPIENTS_NODE})) {
+            foreach my $recipient ($this->{RECIPIENTS_NODE}->getElementsByTagName($RECIPIENT_TAG)) {
+                my $email = $recipient->getAttribute($EMAIL_ATTR);
+                if (defined($email)) {
+                    my $name = $recipient->getAttribute($NAME_ATTR);
+                    push(@recipients, [$email, $name]);
+                }
+            }
+        }
+        
+        $this->{RECIPIENTS_CACHE} = \@recipients;
+    }
+    return $this->{RECIPIENTS_CACHE};
+}
+
 sub get_reminders
 {
     my $this = shift;
@@ -126,7 +154,8 @@ sub get_reminders
                     
                     if ($this->will_occur($days)) {
                         if ($days > 1) {
-                            $this->{WHEN} = "in $days days";
+                            my $upcoming_date = DateCalc("today", "+${days}days");
+                            $this->{WHEN} = "in $days days (" . UnixDate($upcoming_date, "%A %b %e") . ")";
                         }
                         elsif ($days == 1) {		
                             $this->{WHEN} = "tomorrow";
@@ -237,16 +266,4 @@ sub get_id
     return $this->{ID};
 }
 
-sub get_reminder_name()
-{
-    my $this = shift;
-    return $this->{REMINDER_NAME};
-}
-
-sub get_reminder_email()
-{
-    my $this = shift;
-    return $this->{REMINDER_EMAIL};
-}
-
 1;
